pub fn spawn<P, S, R, E, RV, F>(
hbldr: impl FnOnce(&Client<P, S, R, E>) -> Result<F, E>,
) -> Result<(Client<P, S, R, E>, JoinHandle<Option<RV>>), E>Available on crate feature
tokio only.Expand description
Launch a task that will process incoming messages from an ump-ng server end-point.
hbldr is a closure that is expected to return the handler object that
will be responsible for processing received messages.
See top module’s documentation for an overview of the dispatch loop and what the generic parameters are for.
Errors
An application-defined error E is returned if the dispatch loop is
terminated by a handler returning ControlFlow::Break(E).