Function ump_ng_server::task::spawn
source · pub fn spawn<P, S, R, E, RV, F>(
hbldr: impl FnOnce(&Client<P, S, R, E>) -> Result<F, E>
) -> Result<(Client<P, S, R, E>, JoinHandle<Option<RV>>), E>Available on crate feature
tokio only.Expand description
Launch a task that will process incoming messages from an ump-ng server end-point.
See top module’s documentation for an overview of the dispatch loop.