Function ump_ng_server::task::spawn

source ·
pub fn spawn<P, S, R, E, RV>(
    handler: impl Handler<P, S, R, E, RV> + Send + 'static
) -> (Client<P, S, R, E>, JoinHandle<Option<RV>>)where
    P: 'static + Send,
    S: 'static + Send,
    R: 'static + Send,
    E: 'static + Send,
    RV: 'static + Send,
Available on crate feature tokio only.
Launch a task that will process incoming messages from an ump-ng server end-point.

See top module’s documentation for an overview of the dispatch loop.