Function ump_ng_server::thread::spawn
source · pub fn spawn<P, S, R, E, RV, F>(
hbldr: impl FnOnce(&Client<P, S, R, E>) -> F
) -> (Client<P, S, R, E>, JoinHandle<Option<RV>>)Expand description
Launch a thread that will process incoming messages from an ump-ng server end-point.
See top module’s documentation for an overview of the dispatch loop.